Module: Google::Cloud::Optimization

Defined in:
lib/google/cloud/optimization.rb,
lib/google/cloud/optimization/version.rb

Constant Summary collapse

VERSION =
"1.3.0"

Class Method Summary collapse

Class Method Details

.configure {|::Google::Cloud.configure.optimization| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-optimization library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



162
163
164
165
166
# File 'lib/google/cloud/optimization.rb', line 162

def self.configure
  yield ::Google::Cloud.configure.optimization if block_given?

  ::Google::Cloud.configure.optimization
end

.fleet_routing(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for FleetRouting.

By default, this returns an instance of Google::Cloud::Optimization::V1::FleetRouting::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the FleetRouting service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the FleetRouting service. You can determine whether the method will succeed by calling fleet_routing_available?.

About FleetRouting

A service for optimizing vehicle tours.

Validity of certain types of fields:

  • google.protobuf.Timestamp
    • Times are in Unix time: seconds since 1970-01-01T00:00:00+00:00.
    • seconds must be in [0, 253402300799], i.e. in [1970-01-01T00:00:00+00:00, 9999-12-31T23:59:59+00:00].
    • nanos must be unset or set to 0.
  • google.protobuf.Duration
    • seconds must be in [0, 253402300799], i.e. in [1970-01-01T00:00:00+00:00, 9999-12-31T23:59:59+00:00].
    • nanos must be unset or set to 0.
  • google.type.LatLng
    • latitude must be in [-90.0, 90.0].
    • longitude must be in [-180.0, 180.0].
    • at least one of latitude and longitude must be non-zero.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



91
92
93
94
95
96
97
98
99
100
101
# File 'lib/google/cloud/optimization.rb', line 91

def self.fleet_routing version: :v1, transport: :grpc, &block
  require "google/cloud/optimization/#{version.to_s.downcase}"

  package_name = Google::Cloud::Optimization
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Optimization.const_get(package_name).const_get(:FleetRouting)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.fleet_routing_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the FleetRouting service is supported by the current client. If true, you can retrieve a client object by calling fleet_routing. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the FleetRouting service, or if the versioned client gem needs an update to support the FleetRouting service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/google/cloud/optimization.rb', line 115

def self.fleet_routing_available? version: :v1, transport: :grpc
  require "google/cloud/optimization/#{version.to_s.downcase}"
  package_name = Google::Cloud::Optimization
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Optimization.const_get package_name
  return false unless service_module.const_defined? :FleetRouting
  service_module = service_module.const_get :FleetRouting
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end